//
//  TaskManager.m
//  IntegratingRTMTutorial3
//
//  Created by Michael Keith on 2/01/12.
//  Copyright (c) 2012 Ziggurat. All rights reserved.
//

#import "TaskManager.h"
#import "Task.h"
#import "TaskSeries.h"

static TaskManager *_taskManager = nil;

@implementation TaskManager

@synthesize taskSeriesList;

+ (TaskManager *)sharedTaskManager {
	if (!_taskManager)
        _taskManager = [[TaskManager alloc] init];
    return _taskManager;
}

- (id)init {
    self = [super init];
    if (self) {
        self.taskSeriesList = [NSMutableArray array];
    }
    return self;
}

- (void)addTaskSeries:(TaskSeries *)taskSeries {
    if ([self.taskSeriesList indexOfObject:taskSeriesList] == NSNotFound)
        [self.taskSeriesList addObject:taskSeries];
}

- (NSArray *)tasks {
    NSMutableArray *tasks = [NSMutableArray array];
    
    for (TaskSeries *taskSeries in self.taskSeriesList) {
        for (Task *task in taskSeries.tasks) {
            [tasks addObject:task];
        }
    }
    
    [tasks sortUsingComparator:^NSComparisonResult(id a,id b) {
        Task *ta = (Task *)a;
        Task *tb = (Task *)b;
        
        if (ta.dateDue == nil)
            return NSOrderedDescending;
        if (tb.dateDue == nil)
            return NSOrderedAscending;
        return [ta.dateDue compare:tb.dateDue];
    }];
    
    return tasks;
}

@end
